Re: [g-a-devel]patch for gnopernicus; gnome-speech IDL change
- From: Bill Haneman <bill haneman sun com>
- To: Michael Meeks <michael ximian com>
- Cc: accessibility mailing list <gnome-accessibility-devel gnome org>
- Subject: Re: [g-a-devel]patch for gnopernicus; gnome-speech IDL change
- Date: 04 Jun 2002 16:58:42 +0100
On Tue, 2002-06-04 at 13:58, Michael Meeks wrote:
...
> An alternative would be to reinstate the "GNOME" prefix in gnome-speech,
> > put gnome-speech's "Speech" IDL namespace under the "GNOME" module, and
> > change its other clients back.
>
> Which is the correct approach.
After some thought I agree with Michael here.
I have changed the gnome-speech patch to do as Michael suggests and
committed it to CVS; this does however require a slightly larger patch
to gnopernicus, since the gnome-speech methods now are in the "GNOME"
namespace and thus begin with prefix "GNOME_".
gnopernicus patch is attached, may I commit?
-Bill
? speech.patch
Index: speech/libsrs/spgs.c
===================================================================
RCS file: /cvs/gnome/gnopernicus/speech/libsrs/spgs.c,v
retrieving revision 1.3
diff -u -r1.3 spgs.c
--- speech/libsrs/spgs.c 16 May 2002 13:10:42 -0000 1.3
+++ speech/libsrs/spgs.c 4 Jun 2002 13:46:35 -0000
@@ -27,8 +27,8 @@
CORBA_Environment env;
Bonobo_ServerInfoList* servers;
-Speech_SynthesisDriver* drivers;
-Speech_SynthesisDriver curr_driver;
+GNOME_Speech_SynthesisDriver* drivers;
+GNOME_Speech_SynthesisDriver curr_driver;
int last_driver = 0;
@@ -39,7 +39,7 @@
if (curr_driver)
{
- Speech_SynthesisDriver_say (
+ GNOME_Speech_SynthesisDriver_say (
curr_driver,
text,
&env
@@ -87,7 +87,7 @@
if (curr_driver)
{
- Speech_SynthesisDriver_stop (
+ GNOME_Speech_SynthesisDriver_stop (
curr_driver,
&env
);
@@ -105,7 +105,7 @@
fprintf (stderr, "Can't initialize Bonobo.\n");
}
-
+
servers = bonobo_activation_query ("repo_ids.has ('IDL:GNOME/Speech/SynthesisDriver:1.0')",
NULL, &env);
if (env._major != CORBA_NO_EXCEPTION)
@@ -120,12 +120,12 @@
fprintf (stderr, "%d servers found.\n", servers->_length);
- drivers = (Speech_SynthesisDriver*) g_malloc0(servers->_length * sizeof(Speech_SynthesisDriver));
+ drivers = (GNOME_Speech_SynthesisDriver*) g_malloc0(servers->_length * sizeof(GNOME_Speech_SynthesisDriver));
for (i = 0; i < servers->_length; i++)
{
CORBA_Object obj;
- Speech_SynthesisDriver driver;
+ GNOME_Speech_SynthesisDriver driver;
Bonobo_ServerInfo *info;
info = &servers->_buffer[i];
@@ -140,12 +140,12 @@
{
fprintf (stderr, "Activation of server %s succeeded.\n", info->iid);
printf ("Initializing driver...\n");
- driver = (Speech_SynthesisDriver) obj;
- if (Speech_SynthesisDriver_driverInit (driver, &env))
+ driver = (GNOME_Speech_SynthesisDriver) obj;
+ if (GNOME_Speech_SynthesisDriver_driverInit (driver, &env))
{
fprintf (stderr, "Driver initialization succeeded :-).\n");
// fprintf (stderr, "Driver %s initialization succeeded :-).\n", Speech_SynthesisDriver_getDriverName(driver, &env));//!!!!!! THE PROBLEM
drivers[last_driver++] = driver;
}
else
@@ -168,4 +168,3 @@
gs_shut_up();
CORBA_free(servers);
}
-
[
Date Prev][
Date Next] [
@@ -140,12 +140,12 @@
{
fprintf (stderr, "Driver initialization succeeded :-).\n");
-// fprintf (stderr, "Driver %s initialization succeeded :-).\n", Speech_SynthesisDriver_getDriverName(driver, &env));//!!!!!! THE PROBLEM
+// fprintf (stderr, "Driver %s initialization succeeded :-).\n", GNOME_Speech_SynthesisDriver_getDriverName(driver, &env));//!!!!!! THE PROBLEM
drivers[last_driver++] = driver;
}
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]